@@ -337,6 +337,7 @@ class IButtonWidget(IWidget):
                 not issubclass(function.__class__, ButtonFunction)):
             raise ValueError(f"Function type {type(function)} is not a "
                              f"ButtonFunction.")
+        self._active = False
         self.function = function
         # Override lets things like the ButtonGroup take over the function,
         # but doesn't serialize so it won't pollute the serial form
@@ -366,9 +367,9 @@ class IButtonWidget(IWidget):
         """
         super(IButtonWidget, self).release(page)
         if self._function_override:
-            return self._function_override.update(page, self, False)
+            return self._function_override.update(page, self, self._active)
         elif self.function:
-            return self.function.update(page, self, False)
+            return self.function.update(page, self, self._active)
 
     @doc_inherit(IWidget.render, style='numpy_with_merge')
     def render(self, page, surface):
