@@ -33,7 +33,10 @@ class GUI(object):
     # Initialize the event timer
     last_event = pygame.time.get_ticks()
 
-    def __init__(self, touchscreen, bright=None):
+    def __init__(self, touchscreen,
+                 bright=BRIGHT_LEVEL,
+                 fade_time_s=FADE_TIME,
+                 blackout_time_s=BLACKOUT_TIME):
         """ A Graphical User Interface for using a touchscreen.
 
         Parameters
@@ -43,8 +46,16 @@ class GUI(object):
         bright : int
             Brightness level (to balance visibility and screen wear).  Defaults
             to GUI.BRIGHT_LEVEL.
+        fade_time_s : int
+            The number of seconds of inactivity before the screen fades
+            None to never fade
+        blackout_time_s : int
+            The number of seconds of inactivity before the screen blacks out.
+            None to never blackout
         """
-        self._bright_level = bright or self.BRIGHT_LEVEL
+        self._bright_level = bright
+        self._fade_time_s = fade_time_s
+        self._blackout_time_s = blackout_time_s
         self._touchscreen = touchscreen
         self._current_page = None
         self._first_page = None
@@ -153,10 +164,10 @@ class GUI(object):
                 time = pygame.time.get_ticks()
                 # deltaTime in seconds.
                 delta_time = (time - self.last_event) / 1000.0
-                if delta_time > self.BLACKOUT_TIME:
+                if self._blackout_time_s is not None and delta_time > self._blackout_time_s:
                     self.set_light(False)
                     self._blacked = True
-                elif delta_time > self.FADE_TIME:
+                elif self._fade_time_s is not None and delta_time > self._fade_time_s:
                     self.set_brightness(self.FADE_LEVEL)
                     self._faded = True
 
