@@ -241,10 +241,14 @@ class Touchscreen(object):
         return []
 
     def _touch_device(self):
+        print("LOCATE TOUCH DEVICE")
         for evdev in glob.glob("/sys/class/input/event*"):
             try:
+                print(f"... {evdev}")
                 with Path(evdev, 'device', 'name').open(mode='r') as f:
-                    if f.read().strip() == self._device:
+                    device = f.read().strip()
+                    print(f"{device}?")
+                    if device == self._device:
                         return str(Path('/dev', 'input', Path(evdev).name))
             except IOError as e:
                 if e.errno != errno.ENOENT:
