@@ -157,9 +157,13 @@ class Page(object):
             json representation of this Page
         """
         indent = 4 if readable else None
-        return json.dumps(self._do_serialize(self),
+        functions = set()
+
+        serial_page = json.dumps(self._do_serialize(self, functions),
                           indent=indent,
                           sort_keys=True)
+        LOG.info(f"Page {self.name!r} uses:  {functions}")
+        return serial_page
 
     def list_functions(self):
         functions = set()
@@ -289,7 +293,7 @@ class Page(object):
         try:
             m = importlib.import_module(imp)
         except Exception as e:
-            raise ImportError(f"Unable to import {imp!r}: {e}")
+            raise ImportError(f"Unable to import {module!r}.{item}: {e}")
         for part in path[1:]:
             m = getattr(m, part)
         return getattr(m, item)
