@@ -57,7 +57,6 @@ class Button(IButtonWidget):
         super(Button, self).__init__(position, size, **kwargs)
         self.style = style or Button.RECTANGLE
         self.behavior = behavior or Button.CLICK
-        self._active = False
 
     @doc_inherit(IButtonWidget.render, style='numpy_with_merge')
     def render(self, page, surface):
@@ -91,7 +90,7 @@ class Button(IButtonWidget):
             self._active = True
 
             if self._function_override:
-                return self._function_override.update(page, self, False)
+                return self._function_override.update(page, self, self._active)
             elif self.function:
                 return self.function.update(page, self, self._active)
 
@@ -100,7 +99,7 @@ class Button(IButtonWidget):
             self._active = False
 
             if self._function_override:
-                return self._function_override.update(page, self, False)
+                return self._function_override.update(page, self, self._active)
             elif self.function:
                 return self.function.update(page, self, self._active)
 
@@ -119,7 +118,7 @@ class Button(IButtonWidget):
             self._active = True
 
             if self._function_override:
-                return self._function_override.update(page, self, False)
+                return self._function_override.update(page, self, self._active)
             elif self.function:
                 self.function.update(page, self, self._active)
         super(Button, self).press(page)
@@ -207,7 +206,7 @@ class ButtonGroup(IWidgetInterface):
         # Now the actual button press
         btn = next(btn for btn in self._widgets if btn.id == button.id)
         if btn.function:
-            return btn.function.update(page, button, state)
+            return btn.function.update(page, btn, btn._active)
         return None
 
     @property
