@@ -12,6 +12,7 @@ import pygame
 from custom_inherit import doc_inherit
 
 from pi_touch_gui._widget_bases import IControlWidget
+from pi_touch_gui.widget_functions import DialFunction, SliderFunction
 
 LOG = logging.getLogger(__name__)
 
@@ -21,13 +22,24 @@ class Dial(IControlWidget):
     """
 
     @doc_inherit(IControlWidget.__init__, style='numpy_with_merge')
-    def __init__(self, position, size, **kwargs):
+    def __init__(self, position, size, function, **kwargs):
         """ Initialize the dial.
+
+        Parameters
+        ----------
+        function : DialFunction
+            Function to call on dial events, with a new value for the
+            dial.
         """
         # Dials don't use label, so block it
         if kwargs.get('label'):
             raise ValueError("Dials don't use their value as the label.")
 
+        if (function is not None
+                and not issubclass(function.__class__, DialFunction)):
+            raise ValueError(f"Function type {type(function)} is not a "
+                             f"DialFunction.")
+
         self.size = size
         diameter = min(size[0], size[1])
         radius = diameter >> 1
@@ -38,8 +50,10 @@ class Dial(IControlWidget):
         super(Dial, self).__init__(position, (diameter, diameter),
                                    font_size=font_size,
                                    **kwargs)
+        self.function = function
         self._radius = radius
         self._cx, self._cy = (self._x + self._w // 2), (self._y + self._h // 2)
+        self._initialized = False
 
     def touch_inside(self, touch):
         """ The interior of the dial is determined by a circle.
@@ -65,7 +79,11 @@ class Dial(IControlWidget):
 
         super(Dial, self)._on_move(touch)
 
-    def render(self, surface):
+    def render(self, page, surface):
+        if not self._initialized:
+            self.release(page)
+            self._initialized = True
+
         wedge_rect = (self._x, self._y, self._w, self._h)
         handle_pos = (
             int(self._cx + (self._radius * math.cos(self._value * math.tau))),
@@ -88,27 +106,37 @@ class Dial(IControlWidget):
         self.render_centered_text(surface, self.value_str(),
                                   self.label_color1, self.color1)
 
-        if self._focus:
-            self.render_focus(surface)
-
 
 class Slider(IControlWidget):
     """ Variable value input linear slider
     """
 
     @doc_inherit(IControlWidget.__init__, style='numpy_with_merge')
-    def __init__(self, position, size, **kwargs):
+    def __init__(self, position, size, function, **kwargs):
         """ Initialize the slider.
 
         color1 is the slider background fill
         color2 is the slider outline and active value fill
         label_color1 is the slider line (and label)
+
+        Parameters
+        ----------
+        function : SliderFunction
+            Function to call on slider events, with a new value for the
+            dial.
         """
         # Sliders don't use label, so block it
         if kwargs.get('label'):
             raise ValueError("Dials don't use their value as the label.")
 
+        if (function is not None
+                and not issubclass(function.__class__, SliderFunction)):
+            raise ValueError(f"Function type {type(function)} is not a "
+                             f"SliderFunction.")
+
         super(Slider, self).__init__(position, size, **kwargs)
+        self.function = function
+        self._initialized = False
 
     def _on_move(self, touch):
         # If too many touches, bail
@@ -132,11 +160,15 @@ class Slider(IControlWidget):
             if 0 <= y <= self._h:
                 self._value = (self._h - float(y)) / float(self._h)
 
-        self.adjusted_value = self.map_value_to_adjusted_value(self._value)
+        self._adjusted_value = self.map_value_to_adjusted_value(self._value)
 
         super(Slider, self)._on_move(touch)
 
-    def render(self, surface):
+    def render(self, page, surface):
+        if not self._initialized:
+            self.release(page)
+            self._initialized = True
+
         pygame.draw.rect(surface, self.color1, (self.position, self.size), 0)
 
         if self._w > self._h:
@@ -163,6 +195,3 @@ class Slider(IControlWidget):
                          3)
 
         self.render_centered_text(surface, self.value_str(), self.label_color1)
-
-        if self._focus:
-            self.render_focus(surface)
