@@ -8,10 +8,10 @@ import logging
 
 import pygame
 
-from gui import GUI
-from page import Page
+from pi_touch_gui.gui import GUI
+from pi_touch_gui.page import Page
 from pi_touch_gui._utilities import backlog_error
-from raspberrypi_ts import Touchscreen
+from pi_touch_gui.multitouch.raspberrypi_ts import Touchscreen
 from test_pages.pages import get_pages
 
 logging.basicConfig(
